var PrefsAssistant = Class.create({
	initialize: function(appLauncherCfg, quickLaunchCfg, callback) {
		this.appLauncherCfg = appLauncherCfg;
		this.quickLaunchCfg = quickLaunchCfg;	
		
		this.refreshCallback = callback;
		this.refreshQuickLaunch = true;
		
		this.oldGridSize = this.appLauncherCfg.grid;
		this.oldGridSpacing = this.appLauncherCfg.spacing;
		this.oldIconsSize = this.appLauncherCfg.icons;
		this.oldIconTitles = this.appLauncherCfg.titles;
		
		this.oldHeader = this.appLauncherCfg.header;
		this.oldIndicators = this.appLauncherCfg.indicators;
		
		this.oldQLMode = this.quickLaunchCfg.mode;
	},
	
	setup: function() {
		document.body.className = "prefs";

		SystemManagerService.showQuickLaunch(false);
	
		this.choicesPageHeader = [
			{label: $L("No Page Header"), value: "none"},
			{label: $L("Use Page Name"), value: "name"},
			{label: $L("Use Page Tabs"), value: "tabs"}];

		this.modelPageHeader = {value: this.appLauncherCfg.header, disabled: false};

		this.controller.setupWidget("PageHeader", {
			label: $L("Page Header"),
			labelPlacement: "left", 							
			choices: this.choicesPageHeader},
			this.modelPageHeader);

		this.controller.listen(this.controller.get("PageHeader"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));

		this.choicesNewApps = [
			{label: $L("On First Page"), value: "first"},
			{label: $L("On Last Page"), value: "last"},
			{label: $L("On Active Page"), value: "active"},
			{label: $L("On Default Page"), value: "default"}];

		this.modelNewApps = {value: this.appLauncherCfg.placement, disabled: false};

		this.controller.setupWidget("NewApps", {
			label: $L("Put New Apps"),
			labelPlacement: "left", 							
			choices: this.choicesNewApps},
			this.modelNewApps);

		this.controller.listen(this.controller.get("NewApps"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));

		this.modelPageReset = { value: this.appLauncherCfg.reset, disabled: false };

		this.controller.setupWidget('PageReset', 
			{falseLabel: $L("Off"), trueLabel: $L("On")},
		   this.modelPageReset);

		this.controller.listen(this.controller.get("PageReset"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));

		this.modelPageWrap = { value: this.appLauncherCfg.wrap, disabled: false };

		this.controller.setupWidget('PageWrap', 
			{falseLabel: $L("Off"), trueLabel: $L("On")},
		   this.modelPageWrap);

		this.controller.listen(this.controller.get("PageWrap"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));

		if(this.appLauncherCfg.wrap)
			this.modelPageAnim = { value: this.appLauncherCfg.animate, disabled: true };
		else
			this.modelPageAnim = { value: this.appLauncherCfg.animate, disabled: false };

		this.controller.setupWidget('PageAnim', 
			{falseLabel: $L("Off"), trueLabel: $L("On")},
		   this.modelPageAnim);

		this.controller.listen(this.controller.get("PageAnim"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));

		this.modelPageIndicators = { value: this.appLauncherCfg.indicators, disabled: false };

		this.controller.setupWidget('PageIndicators', 
			{falseLabel: $L("Off"), trueLabel: $L("On")},
		   this.modelPageIndicators);

		this.controller.listen(this.controller.get("PageIndicators"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));

		this.choicesIconsGrid = [
			{label: $L("Small"), value: "small"},
			{label: $L("Medium"), value: "medium"},
			{label: $L("Large"), value: "large"}];

		this.modelIconsGrid = {value: this.appLauncherCfg.grid, disabled: false};

		this.controller.setupWidget("IconsGrid", {
			label: $L("Grid Size"),
			labelPlacement: "left", 							
			choices: this.choicesIconsGrid},
			this.modelIconsGrid);

		this.controller.listen(this.controller.get("IconsGrid"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));

		this.controller.get("Spacing").update(this.appLauncherCfg.spacing + " pixels");

		this.modelGridSpacing = {value: this.appLauncherCfg.spacing, disabled: false};

		this.controller.setupWidget("GridSpacing", {'minValue': 0, 'maxValue': 25, 
			'round': true}, this.modelGridSpacing);

		this.controller.listen(this.controller.get("GridSpacing"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));

		this.choicesIconsSize = [
			{label: $L("Small"), value: "small"},
			{label: $L("Medium"), value: "medium"},
			{label: $L("Large"), value: "large"}];

		this.modelIconSize = {value: this.appLauncherCfg.icons, disabled: false};

		this.controller.setupWidget("IconSize", {
			label: $L("Icon Size"),
			labelPlacement: "left", 							
			choices: this.choicesIconsSize},
			this.modelIconSize);

		this.controller.listen(this.controller.get("IconSize"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));
			
		this.modelIconTitles = { value: this.appLauncherCfg.titles, disabled: false };

		this.controller.setupWidget('IconTitles', 
			{falseLabel: $L("Off"), trueLabel: $L("On")},
		   this.modelIconTitles);

		this.controller.listen(this.controller.get("IconTitles"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));
		   
		this.choicesQuickLaunch = [
			{label: $L("Always Visible"), value: "visible"},
			{label: $L("Always Hidden"), value: "hidden"},
			{label: $L("Hide In Launcher"), value: "mixed"},
			{label: $L("Show In Launcher"), value: "launcher"}];

		this.modelQuickLaunch = {value: this.quickLaunchCfg.mode, disabled: false};
			
		this.controller.setupWidget("QuickLaunch", {
			label: $L("Launch Bar"),
			labelPlacement: "left", 							
			choices: this.choicesQuickLaunch},
			this.modelQuickLaunch);

		this.controller.listen(this.controller.get("QuickLaunch"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));

		this.modelReorderUnhide = { value: this.quickLaunchCfg.reorder, disabled: false };

		this.controller.setupWidget('ReorderUnhide', 
			{falseLabel: $L("Off"), trueLabel: $L("On")},
		   this.modelReorderUnhide);

		this.controller.listen(this.controller.get("ReorderUnhide"), Mojo.Event.propertyChange, 
			this.savePreferences.bind(this));

		if((this.quickLaunchCfg.mode == "visible") || (this.quickLaunchCfg.mode == "launcher")) {
			this.controller.get("QuickLaunchRow").removeClassName("first");
			this.controller.get("QuickLaunchRow").addClassName("single");
			this.controller.get("ReorderUnhideRow").hide();
		}			
	},
	
	savePreferences: function(event) {
		if((this.modelQuickLaunch.value == "visible") || (this.modelQuickLaunch.value == "launcher")) {
			this.controller.get("QuickLaunchRow").removeClassName("first");
			this.controller.get("QuickLaunchRow").addClassName("single");
			this.controller.get("ReorderUnhideRow").hide();
		}	
		else {
			this.controller.get("QuickLaunchRow").removeClassName("single");
			this.controller.get("QuickLaunchRow").addClassName("first");
			this.controller.get("ReorderUnhideRow").show();
		}
	
		if(this.modelPageWrap.value) {
			this.modelPageAnim.value = false;
			this.modelPageAnim.disabled = true;
		}
		else
			this.modelPageAnim.disabled = false;

		this.controller.modelChanged(this.modelPageAnim, this);
	
		this.appLauncherCfg.header = this.modelPageHeader.value;
		this.appLauncherCfg.placement = this.modelNewApps.value;

		this.appLauncherCfg.reset = this.modelPageReset.value;
		this.appLauncherCfg.wrap = this.modelPageWrap.value;
		this.appLauncherCfg.animate = this.modelPageAnim.value;
		this.appLauncherCfg.indicators = this.modelPageIndicators.value;

		this.appLauncherCfg.grid = this.modelIconsGrid.value;
		this.appLauncherCfg.spacing = this.modelGridSpacing.value;
		this.appLauncherCfg.icons = this.modelIconSize.value;
		this.appLauncherCfg.titles = this.modelIconTitles.value;

		this.quickLaunchCfg.mode = this.modelQuickLaunch.value;
		this.quickLaunchCfg.reorder = this.modelReorderUnhide.value;
		
		this.controller.get("Spacing").update(this.appLauncherCfg.spacing + " pixels");
	
		if(this.setPreferencesRequest)
			this.setPreferencesRequest.cancel();
		
		this.setPreferencesRequest = new Mojo.Service.Request('palm://com.palm.systemservice/', {
			method: 'setPreferences', parameters: {'appLauncherCfg': this.appLauncherCfg, 
				'quickLaunchCfg': this.quickLaunchCfg} });
	},
	
	handleCommand: function(event) {
		if(event.type == Mojo.Event.back) {
			event.stop();

			this.refreshQuickLaunch = false;

			this.controller.stageController.popScene();
		}
	},
			
	cleanup: function() {
		document.body.className = "palm-default";
		
		document.body.addClassName("grid_" + this.appLauncherCfg.grid);
		document.body.addClassName("icons_" + this.appLauncherCfg.icons);
	
		if(this.appLauncherCfg.titles == false)
			document.body.addClassName("notitles");
		else
			document.body.removeClassName("notitles");
	
		if((this.oldGridSize != this.appLauncherCfg.grid) || 
			(this.oldIconsSize != this.appLauncherCfg.icons) ||
			(this.oldIconTitles != this.appLauncherCfg.titles) ||
			(this.oldHeader != this.appLauncherCfg.header) ||
			(this.oldIndicators != this.appLauncherCfg.indicators) ||
			(this.oldQLMode != this.quickLaunchCfg.mode) ||
			(this.oldGridSpacing != this.appLauncherCfg.spacing))
		{
			this.refreshCallback(true, this.refreshQuickLaunch);
		}
		else
			this.refreshCallback(false, this.refreshQuickLaunch);
	}
});

